@@ -3,7 +3,12 @@
 # This file is part of dj-revproxy released under the MIT license. 
 # See the NOTICE for more information.
 
-version_info = (0, 2, 0)
+version_info = (0, 2, 1)
 __version__ =  ".".join(map(str, version_info))
 
-from revproxy.proxy import proxy_request, RevProxy, site_proxy
+try:
+    from revproxy.proxy import proxy_request, RevProxy, site_proxy
+except ImportError:
+    import traceback
+    traceback.print_exc()
+    
